(this.webpackJsonpstreamlit_component_template=this.webpackJsonpstreamlit_component_template||[]).push([[0],{14:function(e,t,n){e.exports={poCheckboxLabel:"style_poCheckboxLabel__2IHB4",poCheckboxSpan:"style_poCheckboxSpan__ltXcy",poCheckbox:"style_poCheckbox__3Q56z"}},18:function(e,t,n){e.exports=n(26)},26:function(e,t,n){"use strict";n.r(t);var o,a=n(8),c=n.n(a),s=n(16),r=n.n(s),i=n(6),l=n(0),u=n(1),p=n(2),h=n(3),d=n(11),k=n(14),b=n.n(k);!function(e){e[e.sketchup=0]="sketchup",e[e.rhino=1]="rhino",e[e.revit=2]="revit"}(o||(o={}));var m=function(e){Object(p.a)(n,e);var t=Object(h.a)(n);function n(e){var a;Object(u.a)(this,n),(a=t.call(this,e)).render=function(){return c.a.createElement("label",{className:b.a.poCheckboxLabel},c.a.createElement("input",{className:b.a.poCheckbox,type:"checkbox",defaultChecked:a.state.defaultChecked,onChange:a._onChange,disabled:a.props.disabled,onFocus:a._onFocus,onBlur:a._onBlur}),c.a.createElement("span",{className:b.a.poCheckboxSpan},"Sync"))},a._genToken=function(e){var t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:"rhino",n=a.state.delay;if(console.log(a.state.delay),t==o[o.rhino]){var c=function(t){return new Promise((function(n,o){return setTimeout((function(){var t=window.parent.chrome.webview.hostObjects.sync.connection.PassToken(e);n(t)}),t)}))};a.state.isChecked&&c(n).then((function(e){d.a.setComponentValue(e)}))}else t==o[o.sketchup]&&a.state.isChecked&&setTimeout((function(){return d.a.setComponentValue(e)}),n)},a._onChange=function(e){var t=e.target.checked;a.setState({isChecked:t})},a._onFocus=function(){a.setState({isFocused:!0})},a._onBlur=function(){a.setState({isFocused:!1})};var s=a.props.args.default_checked,r={defaultChecked:s,isChecked:!!s,delay:a.props.args.delay};return a.state=Object(i.a)({},r),window.parent.genPollinationToken=a._genToken,a}return Object(l.a)(n)}(d.b),_=Object(d.c)(m);r.a.render(c.a.createElement(c.a.StrictMode,null,c.a.createElement(_,null)),document.getElementById("root"))}},[[18,1,2]]]);
//# sourceMappingURL=main.4cb49abe.chunk.js.map